Changelog
---------

Here you can see the full list of changes between each Inflection release.

0.2.0 (June 15, 2013)
+++++++++++++++++++++

- Added initial support for Python 3.
- Dropped Python 2.5 support.

0.1.2 (March 13, 2012)
++++++++++++++++++++++

- Added Python 2.5 support.

0.1.1 (February 24, 2012)
+++++++++++++++++++++++++

- Fixed some files not included in the distribution package.

0.1.0 (February 24, 2012)
+++++++++++++++++++++++++

- Initial public release
